diff --git a/src/components/GenerateCourse/AICourseLimit.tsx b/src/components/GenerateCourse/AICourseLimit.tsx
index 5dac1a284..efba35c2b 100644
--- a/src/components/GenerateCourse/AICourseLimit.tsx
+++ b/src/components/GenerateCourse/AICourseLimit.tsx
@@ -31,19 +31,22 @@ export function AICourseLimit(props: AICourseLimitProps) {
const totalPercentage = getPercentage(used, limit);
- // has consumed 80% of the limit
- const isNearLimit = used >= limit * 0.8;
+ // has consumed 85% of the limit
+ const isNearLimit = used >= limit * 0.85;
const isPaidUser = userBillingDetails.status === 'active';
return (
<>
-
+ {!isPaidUser ||
+ (isNearLimit && (
+
+ ))}
{(!isPaidUser || isNearLimit) && (